@@ -1,4 +1,4 @@
-require 'puppet/provider/keystone'
+require File.join(File.dirname(__FILE__), '..','..','..', 'puppet/provider/keystone')
 
 Puppet::Type.type(:keystone_endpoint).provide(
   :openstack,
@@ -9,40 +9,42 @@ Puppet::Type.type(:keystone_endpoint).provide(
 
   include PuppetX::Keystone::CompositeNamevar::Helpers
 
-  @endpoints   = nil
-  @services    = nil
-  @credentials = Puppet::Provider::Openstack::CredentialsV3.new
+  attr_accessor :property_hash, :property_flush
+
+  @endpoints     = nil
+  @services      = nil
+  @credentials   = Puppet::Provider::Openstack::CredentialsV3.new
+  @do_not_manage = false
 
   def initialize(value={})
     super(value)
     @property_flush = {}
   end
 
+  def self.do_not_manage
+    @do_not_manage
+  end
+
+  def self.do_not_manage=(value)
+    @do_not_manage = value
+  end
+
   def create
-    # Reset the cache.
-    self.class.services = nil
+    if self.class.do_not_manage
+      fail("Not managing Keystone_endpoint[#{@resource[:name]}] due to earlier Keystone API failures.")
+    end
     name   = resource[:name]
     region = resource[:region]
     type   = resource[:type]
     type   = self.class.type_from_service(name) unless set?(:type)
     @property_hash[:type] = type
-    services = self.class.services.find_all { |s| s[:name] == name }
-    service = services.find { |s| s[:type] == type }
-
-    if service.nil? && services.count == 1
-      # For backward comptatibility, match the service by name only.
-      name = services[0][:id]
-    else
-      # Math the service by id.
-      name = service[:id] if service
-    end
     ids = []
-
+    s_id = service_id
     created = false
     [:admin_url, :internal_url, :public_url].each do |scope|
       if resource[scope]
         created = true
-        ids << endpoint_create(name, region,  scope.to_s.sub(/_url$/, ''),
+        ids << endpoint_create(s_id, region, scope.to_s.sub(/_url$/, ''),
                                resource[scope])[:id]
       end
     end
@@ -58,6 +60,9 @@ Puppet::Type.type(:keystone_endpoint).provide(
   end
 
   def destroy
+    if self.class.do_not_manage
+      fail("Not managing Keystone_endpoint[#{@resource[:name]}] due to earlier Keystone API failures.")
+    end
     ids = @property_hash[:id].split(',')
     ids.each do |id|
       self.class.request('endpoint', 'delete', id)
@@ -72,14 +77,23 @@ Puppet::Type.type(:keystone_endpoint).provide(
   mk_resource_methods
 
   def public_url=(value)
+    if self.class.do_not_manage
+      fail("Not managing Keystone_endpoint[#{@resource[:name]}] due to earlier Keystone API failures.")
+    end
     @property_flush[:public_url] = value
   end
 
   def internal_url=(value)
+    if self.class.do_not_manage
+      fail("Not managing Keystone_endpoint[#{@resource[:name]}] due to earlier Keystone API failures.")
+    end
     @property_flush[:internal_url] = value
   end
 
   def admin_url=(value)
+    if self.class.do_not_manage
+      fail("Not managing Keystone_endpoint[#{@resource[:name]}] due to earlier Keystone API failures.")
+    end
     @property_flush[:admin_url] = value
   end
 
@@ -98,7 +112,8 @@ Puppet::Type.type(:keystone_endpoint).provide(
         endpoints.each do |ep_osc|
           if (ep_osc[:id] != current[:id]) &&
             (ep_osc[:service_name] == current[:service_name]) &&
-            (ep_osc[:service_type] == current[:service_type])
+            (ep_osc[:service_type] == current[:service_type]) &&
+            (ep_osc[:region] == current[:region])
             endpoint.merge!(ep_osc[:interface].to_sym => ep_osc)
           end
         end
@@ -109,11 +124,11 @@ Puppet::Type.type(:keystone_endpoint).provide(
       new(
         :name         => endpoint[:name],
         :ensure       => :present,
-        :id           => "#{endpoint[:admin][:id]},#{endpoint[:internal][:id]},#{endpoint[:public][:id]}",
-        :region       => endpoint[:admin][:region],
-        :admin_url    => endpoint[:admin][:url],
-        :internal_url => endpoint[:internal][:url],
-        :public_url   => endpoint[:public][:url]
+        :id           => make_id(endpoint),
+        :region       => get_region(endpoint),
+        :admin_url    => get_url(endpoint, :admin),
+        :internal_url => get_url(endpoint, :internal),
+        :public_url   => get_url(endpoint, :public)
       )
     end
   end
@@ -128,19 +143,27 @@ Puppet::Type.type(:keystone_endpoint).provide(
   end
 
   def flush
-    if @property_flush && @property_hash[:id]
-      ids = @property_hash[:id].split(',')
-      if @property_flush[:admin_url]
-        self.class.request('endpoint', 'set', [ids[0], "--url=#{resource[:admin_url]}"])
-      end
-      if @property_flush[:internal_url]
-        self.class.request('endpoint', 'set', [ids[1], "--url=#{resource[:internal_url]}"])
-      end
-      if @property_flush[:public_url]
-        self.class.request('endpoint', 'set', [ids[2], "--url=#{resource[:public_url]}"])
+    if property_flush && property_hash[:id]
+      scopes = [:admin_url, :internal_url, :public_url]
+      ids = Hash[scopes.zip(property_hash[:id].split(','))]
+      scopes.each do |scope|
+        if property_flush[scope]
+          if ids[scope].nil? || ids[scope].empty?
+            ids[scope] = endpoint_create(service_id, resource[:region],
+                                         scope.to_s.sub(/_url$/, ''),
+                                         property_flush[scope])[:id]
+          else
+            self.class.request('endpoint',
+                               'set',
+                               [ids[scope],
+                                "--url=#{resource[scope]}"])
+          end
+        end
       end
+      @property_hash = resource.to_hash
+      @property_hash[:id] = scopes.map { |s| ids[s] }.join(',')
+      @property_hash[:ensure] = :present
     end
-    @property_hash = resource.to_hash
   end
 
   private
@@ -154,7 +177,11 @@ Puppet::Type.type(:keystone_endpoint).provide(
 
   def self.endpoints
     return @endpoints unless @endpoints.nil?
+    prev_do_not_manage = self.do_not_manage
+    self.do_not_manage = true
     @endpoints = request('endpoint', 'list')
+    self.do_not_manage = prev_do_not_manage
+    @endpoints
   end
 
   def self.endpoints=(value)
@@ -163,7 +190,11 @@ Puppet::Type.type(:keystone_endpoint).provide(
 
   def self.services
     return @services unless @services.nil?
+    prev_do_not_manage = self.do_not_manage
+    self.do_not_manage = true
     @services = request('service', 'list')
+    self.do_not_manage = prev_do_not_manage
+    @services
   end
 
   def self.services=(value)
@@ -219,4 +250,47 @@ Puppet::Type.type(:keystone_endpoint).provide(
       "#{region}/#{name}::#{type}"
     end
   end
+
+  def self.make_id(endpoint)
+    id_str = ''
+    id_sep = ''
+    [:admin, :internal, :public].each do |type|
+      id_str += "#{id_sep}#{endpoint[type][:id]}" if endpoint[type]
+      id_sep = ','
+    end
+    id_str
+  end
+
+  def self.get_region(endpoint)
+    type = [:admin, :internal, :public].detect { |t| endpoint.key? t }
+    type ? endpoint[type][:region] : ''
+  end
+
+  def self.get_url(endpoint, type, default='')
+    endpoint[type][:url] rescue default
+  end
+
+  def service_id
+    # Reset the cache.
+    self.class.services = nil
+    name = resource[:name]
+    type = resource[:type]
+
+    services = self.class.services.find_all { |s| s[:name] == name }
+    service = services.find { |s| s[:type] == type }
+    service_id = ''
+    if service.nil? && services.count == 1
+      # For backward comptatibility, match the service by name only.
+      service_id = services[0][:id]
+    else
+      # Math the service by id.
+      service_id = service[:id] if service
+    end
+    if service_id.nil? || service_id.empty?
+      title = self.class.transform_name(resource[:region], resource[:name], resource[:type])
+      fail(Puppet::Error, "Cannot find service associated with #{title}")
+    end
+
+    service_id
+  end
 end
