@@ -21,8 +21,6 @@ describe 'keystone' do
   default_params = {
       'package_ensure'                     => 'present',
       'client_package_ensure'              => 'present',
-      'public_bind_host'                   => '0.0.0.0',
-      'public_port'                        => '5000',
       'catalog_type'                       => 'sql',
       'catalog_driver'                     => false,
       'token_provider'                     => 'fernet',
@@ -30,10 +28,6 @@ describe 'keystone' do
       'password_hash_rounds'               => '<SERVICE DEFAULT>',
       'revoke_driver'                      => 'sql',
       'revoke_by_id'                       => true,
-      'cache_backend'                      => '<SERVICE DEFAULT>',
-      'cache_backend_argument'             => '<SERVICE DEFAULT>',
-      'cache_enabled'                      => '<SERVICE DEFAULT>',
-      'cache_memcache_servers'             => '<SERVICE DEFAULT>',
       'enable_ssl'                         => false,
       'ssl_certfile'                       => '/etc/keystone/ssl/certs/keystone.pem',
       'ssl_keyfile'                        => '/etc/keystone/ssl/private/keystonekey.pem',
@@ -59,8 +53,6 @@ describe 'keystone' do
   override_params = {
       'package_ensure'                     => 'latest',
       'client_package_ensure'              => 'latest',
-      'public_bind_host'                   => '0.0.0.0',
-      'public_port'                        => '5001',
       'catalog_type'                       => 'template',
       'token_provider'                     => 'uuid',
       'password_hash_algorithm'            => 'pbkdf2_sha512',
@@ -164,7 +156,7 @@ describe 'keystone' do
       if param_hash['public_endpoint']
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value(param_hash['public_endpoint'])
       else
-        is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')
+        is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -265,45 +257,6 @@ describe 'keystone' do
     ) }
   end
 
-  describe 'when public_bind_host or public_bind_port are set' do
-    describe 'when ipv6 loopback is set' do
-      let :params do
-        {
-          :public_bind_host => '::0'
-        }
-      end
-      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[::1]:5000') }
-    end
-
-    describe 'when ipv4 address is set' do
-      let :params do
-        {
-          :public_bind_host => '192.168.0.1',
-          :public_port      => '15000'
-        }
-      end
-      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://192.168.0.1:15000') }
-    end
-
-    describe 'when unenclosed ipv6 address is set' do
-      let :params do
-        {
-          :public_bind_host => '2001:db8::1'
-        }
-      end
-      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[2001:db8::1]:5000') }
-    end
-
-    describe 'when enclosed ipv6 address is set' do
-      let :params do
-        {
-          :public_bind_host => '[2001:db8::1]'
-        }
-      end
-      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[2001:db8::1]:5000') }
-    end
-  end
-
   describe 'when using invalid service name for keystone' do
     let (:params) { {'service_name' => 'foo'}.merge(default_params) }
 
@@ -384,7 +337,6 @@ describe 'keystone' do
     let :params do
       {
         'enable_ssl'      => true,
-        'public_endpoint' => 'https://localhost:5000',
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(true)}
@@ -393,7 +345,6 @@ describe 'keystone' do
     it {is_expected.to contain_keystone_config('ssl/ca_certs').with_value('/etc/keystone/ssl/certs/ca.pem')}
     it {is_expected.to contain_keystone_config('ssl/ca_key').with_value('/etc/keystone/ssl/private/cakey.pem')}
     it {is_expected.to contain_keystone_config('ssl/cert_subject').with_value('/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost')}
-    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('https://localhost:5000')}
   end
 
   describe 'when disabling SSL' do
@@ -403,7 +354,6 @@ describe 'keystone' do
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(false)}
-    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')}
   end
 
   describe 'not setting notification settings by default' do
@@ -478,7 +428,7 @@ describe 'keystone' do
       })
     end
 
-    it { is_expected.to contain_keystone_config('oslo_messaging_notifications/driver').with_value('keystone.openstack.common.notifier.rpc_notifier') }
+    it { is_expected.to contain_keystone_config('oslo_messaging_notifications/driver').with_value(['keystone.openstack.common.notifier.rpc_notifier']) }
     it { is_expected.to contain_keystone_config('oslo_messaging_notifications/topics').with_value('notifications') }
     it { is_expected.to contain_keystone_config('DEFAULT/notification_format').with_value('cadf') }
     it { is_expected.to contain_keystone_config('DEFAULT/control_exchange').with_value('keystone') }
@@ -733,6 +683,7 @@ describe 'keystone' do
       'mode'      => '0600',
       'replace'   => true,
       'subscribe' => 'Anchor[keystone::install::end]',
+      'tag'       => 'keystone-fernet-key',
     )}
     it { is_expected.to contain_file('/etc/keystone/fernet-keys/1').with(
       'content'   => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
@@ -740,6 +691,7 @@ describe 'keystone' do
       'mode'      => '0600',
       'replace'   => true,
       'subscribe' => 'Anchor[keystone::install::end]',
+      'tag'       => 'keystone-fernet-key',
     )}
   end
 
